@@ -14,8 +14,7 @@
  *  Library General Public License for more details.
  *
  *  You should have received a copy of the GNU Library General Public
- *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  License along with this library; if not, see <http://www.gnu.org/licenses/>.
  * 
  *  Author:  Raffaele Sandrini <rasa@gmx.ch>
  *
@@ -23,9 +22,20 @@
 
 #include <config.h>
 #include "nautilus-menu.h"
-#include "nautilus-extension-i18n.h"
 
 #include <glib.h>
+#include <glib/gi18n-lib.h>
+
+/**
+ * SECTION:nautilus-menu
+ * @title: NautilusMenu
+ * @short_description: Menu descriptor object
+ * @include: libnautilus-extension/nautilus-menu.h
+ *
+ * #NautilusMenu is an object that describes a submenu in a file manager
+ * menu. Extensions can provide #NautilusMenu objects by attaching them to
+ * #NautilusMenuItem objects, using nautilus_menu_item_set_submenu().
+ */
 
 #define NAUTILUS_MENU_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), NAUTILUS_TYPE_MENU, NautilusMenuPrivate))
 G_DEFINE_TYPE (NautilusMenu, nautilus_menu, G_TYPE_OBJECT);
