@@ -170,6 +170,7 @@ char *                  nautilus_file_get_thumbnail_path                (Nautilu
 gboolean                nautilus_file_can_get_size                      (NautilusFile                   *file);
 goffset                 nautilus_file_get_size                          (NautilusFile                   *file);
 time_t                  nautilus_file_get_mtime                         (NautilusFile                   *file);
+time_t                  nautilus_file_get_atime                         (NautilusFile                   *file);
 GFileType               nautilus_file_get_file_type                     (NautilusFile                   *file);
 char *                  nautilus_file_get_mime_type                     (NautilusFile                   *file);
 char *                  nautilus_file_get_extension                     (NautilusFile                   *file);
@@ -478,6 +479,10 @@ typedef enum {
 	NAUTILUS_DATE_TYPE_TRASHED
 } NautilusDateType;
 
+gboolean                nautilus_file_get_date                          (NautilusFile                   *file,
+                                                                         NautilusDateType                date_type,
+                                                                         time_t                         *date);
+
 typedef struct {
 	GObjectClass parent_slot;
 
