@@ -165,7 +165,6 @@ nautilus_desktop_window_constructed (GObject *obj)
 {
 	AtkObject *accessible;
 	NautilusDesktopWindow *window = NAUTILUS_DESKTOP_WINDOW (obj);
-        GdkRGBA transparent = {0, 0, 0, 0};
 
 	G_OBJECT_CLASS (nautilus_desktop_window_parent_class)->constructed (obj);
 
@@ -203,7 +202,6 @@ nautilus_desktop_window_constructed (GObject *obj)
 		 * Note that nautilus_desktop_window_init is too early to do this.
 		 */
 		nautilus_desktop_window_update_directory (window);
-		gtk_widget_override_background_color (GTK_WIDGET (window), 0, &transparent);
 
 		/* We realize it immediately so that the NAUTILUS_DESKTOP_WINDOW_ID
 		 * property is set so gnome-settings-daemon doesn't try to set
@@ -391,6 +389,8 @@ nautilus_desktop_window_class_init (NautilusDesktopWindowClass *klass)
 	nclass->sync_title = real_sync_title;
 	nclass->close = real_window_close;
 
+	gtk_widget_class_set_css_name (wclass, "nautilus-desktop-window");
+
 	g_type_class_add_private (klass, sizeof (NautilusDesktopWindowDetails));
 }
 
