@@ -1600,10 +1600,14 @@ nautilus_path_bar_update_button_appearance (ButtonData *button_data)
 	icon = get_gicon (button_data);
 	if (icon != NULL) {
 		gtk_image_set_from_gicon (GTK_IMAGE (button_data->image), icon, GTK_ICON_SIZE_MENU);
+		gtk_style_context_add_class (gtk_widget_get_style_context (button_data->button),
+					     "image-button");
 		gtk_widget_show (GTK_WIDGET (button_data->image));
 		g_object_unref (icon);
 	} else {
 		gtk_widget_hide (GTK_WIDGET (button_data->image));
+		gtk_style_context_remove_class (gtk_widget_get_style_context (button_data->button),
+					        "image-button");
 	}
 }
 
