@@ -1,4 +1,4 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 8; tab-width: 8 -*- */
 
 /*
  * Nautilus
@@ -31,6 +31,7 @@
 #include "nautilus-window.h"
 #include "nautilus-progress-info-widget.h"
 #include "nautilus-application.h"
+#include "nautilus-desktop-window.h"
 
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-ui-utilities.h>
@@ -601,8 +602,15 @@ update_operations (NautilusToolbar *self)
                 gtk_widget_queue_draw (self->priv->operations_icon);
 
                 /* Show the popover at start to increase visibility */
-                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->operations_button),
-                                              TRUE);
+                if (!NAUTILUS_IS_DESKTOP_WINDOW (self->priv->window)) {
+                        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->operations_button),
+                                                      TRUE);
+                }
+        }
+
+        /* Since we removed the info widgets, we need to restore the focus */
+        if (gtk_widget_get_visible (self->priv->operations_popover)) {
+                gtk_widget_grab_focus (self->priv->operations_popover);
         }
 }
 
@@ -787,6 +795,10 @@ nautilus_toolbar_init (NautilusToolbar *self)
 			  G_CALLBACK (navigation_button_press_cb), self);
 	g_signal_connect (self->priv->forward_button, "button-release-event",
 			  G_CALLBACK (navigation_button_release_cb), self);
+        g_signal_connect (self->priv->operations_popover, "show",
+                          (GCallback) gtk_widget_grab_focus, NULL);
+        g_signal_connect_swapped (self->priv->operations_popover, "closed",
+                                  (GCallback) gtk_widget_grab_focus, self);
 
 	gtk_widget_show_all (GTK_WIDGET (self));
 	toolbar_update_appearance (self);
@@ -883,6 +895,7 @@ nautilus_toolbar_class_init (NautilusToolbarClass *klass)
 
 	gtk_widget_class_bind_template_child_private (widget_class, NautilusToolbar, operations_button);
 	gtk_widget_class_bind_template_child_private (widget_class, NautilusToolbar, operations_icon);
+	gtk_widget_class_bind_template_child_private (widget_class, NautilusToolbar, operations_popover);
 	gtk_widget_class_bind_template_child_private (widget_class, NautilusToolbar, operations_container);
 	gtk_widget_class_bind_template_child_private (widget_class, NautilusToolbar, operations_revealer);
 	gtk_widget_class_bind_template_child_private (widget_class, NautilusToolbar, view_button);
