@@ -795,7 +795,10 @@ nautilus_window_sync_allow_stop (NautilusWindow *window,
 			update_cursor (window);
 		}
 
-		nautilus_notebook_sync_loading (NAUTILUS_NOTEBOOK (window->priv->notebook), slot);
+                /* Avoid updating the notebook if we are calling on dispose or
+                 * on removal of a notebook tab */
+                if (nautilus_notebook_contains_slot (NAUTILUS_NOTEBOOK (window->priv->notebook), slot))
+                        nautilus_notebook_sync_loading (NAUTILUS_NOTEBOOK (window->priv->notebook), slot);
 	}
 }
 
@@ -936,12 +939,12 @@ static void
 notify_unmount_done (GMountOperation *op,
                      const gchar     *message)
 {
-  GApplication *application;
+  NautilusApplication *application;
   gchar *notification_id;
 
-  application = g_application_get_default ();
+  application = nautilus_application_get_default ();
   notification_id = g_strdup_printf ("nautilus-mount-operation-%p", op);
-  g_application_withdraw_notification (application, notification_id);
+  nautilus_application_withdraw_notification (application, notification_id);
 
   if (message != NULL)
     {
@@ -955,7 +958,7 @@ notify_unmount_done (GMountOperation *op,
       g_notification_set_body (unplug, strings[1]);
       g_notification_set_icon (unplug, icon);
 
-      g_application_send_notification (application, notification_id, unplug);
+      nautilus_application_send_notification (application, notification_id, unplug);
       g_object_unref (unplug);
       g_object_unref (icon);
       g_strfreev (strings);
@@ -968,13 +971,13 @@ static void
 notify_unmount_show (GMountOperation *op,
                      const gchar     *message)
 {
-  GApplication *application;
+  NautilusApplication *application;
   GNotification *unmount;
   gchar *notification_id;
   GIcon *icon;
   gchar **strings;
 
-  application = g_application_get_default ();
+  application = nautilus_application_get_default ();
   strings = g_strsplit (message, "\n", 0);
   icon = g_themed_icon_new ("media-removable");
 
@@ -984,7 +987,7 @@ notify_unmount_show (GMountOperation *op,
   g_notification_set_priority (unmount, G_NOTIFICATION_PRIORITY_URGENT);
 
   notification_id = g_strdup_printf ("nautilus-mount-operation-%p", op);
-  g_application_send_notification (application, notification_id, unmount);
+  nautilus_application_send_notification (application, notification_id, unmount);
   g_object_unref (unmount);
   g_object_unref (icon);
   g_strfreev (strings);
@@ -1034,8 +1037,8 @@ places_sidebar_show_error_message_cb (GtkPlacesSidebar *sidebar,
 }
 
 static void
-places_sidebar_show_other_locations (NautilusWindow   *window,
-                                     GtkPlacesOpenFlags open_flags)
+places_sidebar_show_other_locations_with_flags (NautilusWindow     *window,
+                                                GtkPlacesOpenFlags  open_flags)
 {
         GFile *location;
 
@@ -1621,7 +1624,9 @@ nautilus_window_on_undo_changed (NautilusFileUndoManager *manager,
 			g_free (label);
 		}
 		g_list_free (files);
-	}
+        } else {
+                hide_notification_delete (window);
+        }
 }
 
 static void
@@ -2591,7 +2596,7 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	gtk_widget_class_bind_template_child_private (wclass, NautilusWindow, notification_operation_open);
 	gtk_widget_class_bind_template_child_private (wclass, NautilusWindow, notification_operation_close);
 
-        gtk_widget_class_bind_template_callback (wclass, places_sidebar_show_other_locations);
+        gtk_widget_class_bind_template_callback (wclass, places_sidebar_show_other_locations_with_flags);
 
 	properties[PROP_DISABLE_CHROME] =
 		g_param_spec_boolean ("disable-chrome",
@@ -2734,3 +2739,16 @@ nautilus_window_show_about_dialog (NautilusWindow *window)
 			      "logo-icon-name", "system-file-manager",
 			      NULL);
 }
+
+void
+nautilus_window_search (NautilusWindow *window,
+                        const gchar    *text)
+{
+        NautilusWindowSlot *active_slot;
+
+        active_slot = nautilus_window_get_active_slot (window);
+        if (active_slot)
+                nautilus_window_slot_search (active_slot, text);
+        else
+                g_warning ("Trying search on a slot but no active slot present");
+}
